@@ -1,9 +1,13 @@
 #define QT_FEATURE_clock_gettime 1
 
+#define QT_FEATURE_copy_file_range -1
+
 #define QT_FEATURE_doubleconversion 1
 
 #define QT_FEATURE_system_doubleconversion 1
 
+#define QT_FEATURE_broken_threadlocal_dtors -1
+
 #define QT_FEATURE_dladdr 1
 
 #define QT_FEATURE_futimens 1
@@ -14,18 +18,24 @@
 
 #define QT_FEATURE_glib 1
 
-#define QT_FEATURE_glibc 1
-
 #define QT_FEATURE_icu 1
 
+#define QT_FEATURE_winsdkicu -1
+
 #define QT_FEATURE_inotify 1
 
+#define QT_FEATURE_jemalloc -1
+
 #define QT_FEATURE_journald 1
 
 #define QT_FEATURE_system_libb2 1
 
 #define QT_FEATURE_linkat 1
 
+#define QT_FEATURE_memmem 1
+
+#define QT_FEATURE_memrchr 1
+
 #define QT_FEATURE_mimetype_database 1
 
 #define QT_FEATURE_system_pcre2 1
@@ -38,24 +48,48 @@
 
 #define QT_FEATURE_poll_select -1
 
+#define QT_FEATURE_posix_sem 1
+
+#define QT_FEATURE_posix_shm 1
+
+#define QT_FEATURE_pthread_clockjoin 1
+
+#define QT_FEATURE_pthread_condattr_setclock 1
+
+#define QT_FEATURE_pthread_timedjoin 1
+
 #define QT_FEATURE_qqnx_pps -1
 
 #define QT_FEATURE_renameat2 1
 
 #define QT_FEATURE_slog2 -1
 
-#define QT_FEATURE_statx 1
-
 #define QT_FEATURE_syslog -1
 
+#define QT_FEATURE_sysv_sem 1
+
+#define QT_FEATURE_sysv_shm 1
+
+#define QT_FEATURE_dup3 1
+
+#define QT_FEATURE_accept4 1
+
+#define QT_FEATURE_vxpipedrv -1
+
 #define QT_FEATURE_backtrace 1
 
+#define QT_FEATURE_cxx20_format 1
+
+#define QT_FEATURE_cxx23_stacktrace -1
+
 #define QT_FEATURE_cpp_winrt -1
 
 #define QT_FEATURE_sha3_fast 1
 
 #define QT_FEATURE_hijricalendar 1
 
+#define QT_FEATURE_timezone_locale 1
+
 #define QT_FEATURE_datetimeparser 1
 
 #define QT_FEATURE_lttng -1
@@ -68,3 +102,5 @@
 
 #define QT_FEATURE_poll_exit_on_error -1
 
+#define QT_FEATURE_openssl_hash -1
+
